import * as vue_demi from 'vue-demi';
import { PropType, MaybeRef } from 'vue-demi';
import * as emoji_picker_element_shared from 'emoji-picker-element/shared';
import { EmojiClickEvent, SkinToneChangeEvent } from 'emoji-picker-element/shared';
export { CustomEmoji, DatabaseConstructorOptions, EmojiClickEventDetail, EmojiSkin, I18n, I18nCategories, NativeEmoji, PickerConstructorOptions, SkinTone, SkinToneChangeEventDetail } from 'emoji-picker-element/shared';
import Picker from 'emoji-picker-element/picker';
import Database from 'emoji-picker-element/database';

declare const _default: vue_demi.DefineComponent<{
    isDark: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    skinToneEmoji: StringConstructor;
    customEmoji: PropType<emoji_picker_element_shared.CustomEmoji[] | undefined>;
    dataSource: StringConstructor;
    locale: StringConstructor;
    customCategorySorting: PropType<(a: string, b: string) => number>;
    i18n: PropType<emoji_picker_element_shared.I18n | undefined>;
    pickerStyle: PropType<VuemojiPickerStyle>;
}, unknown, {
    picker: Picker;
}, {}, {
    handleClick(event: EmojiClickEvent): void;
    handleSkinToneChange(event: SkinToneChangeEvent): void;
    updatePickerProps(): void;
    updatePickerStyle(): void;
}, vue_demi.ComponentOptionsMixin, vue_demi.ComponentOptionsMixin, ("emojiClick" | "skinToneChange")[], "emojiClick" | "skinToneChange", vue_demi.PublicProps, Readonly<vue_demi.ExtractPropTypes<{
    isDark: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    skinToneEmoji: StringConstructor;
    customEmoji: PropType<emoji_picker_element_shared.CustomEmoji[] | undefined>;
    dataSource: StringConstructor;
    locale: StringConstructor;
    customCategorySorting: PropType<(a: string, b: string) => number>;
    i18n: PropType<emoji_picker_element_shared.I18n | undefined>;
    pickerStyle: PropType<VuemojiPickerStyle>;
}>> & {
    onEmojiClick?: ((...args: any[]) => any) | undefined;
    onSkinToneChange?: ((...args: any[]) => any) | undefined;
}, {
    isDark: boolean;
}, {}>;

declare function useDatabase(): Database;
/**
 * Returns all emoji matching the given search query, ordered by order.
 */
declare function useEmojiBySearchQuery(query: MaybeRef<string>): {
    result: vue_demi.Ref<({
        name: string;
        shortcodes?: string[] | undefined;
        url: string;
        category?: string | undefined;
    } | {
        annotation: string;
        emoticon?: string | undefined;
        group: number;
        name: string;
        order: number;
        shortcodes?: string[] | undefined;
        tags?: string[] | undefined;
        version: number;
        unicode: string;
        skins?: {
            tone: emoji_picker_element_shared.SkinTone;
            unicode: string;
            version: number;
        }[] | undefined;
    })[]>;
    loading: vue_demi.Ref<boolean>;
};
/**
 * Returns all emoji belonging to a group, ordered by order. Only returns native emoji; custom emoji don't belong to a group.
 */
declare function useEmojiByGroup(group: MaybeRef<number>): {
    result: vue_demi.Ref<{
        annotation: string;
        emoticon?: string | undefined;
        group: number;
        name: string;
        order: number;
        shortcodes?: string[] | undefined;
        tags?: string[] | undefined;
        version: number;
        unicode: string;
        skins?: {
            tone: emoji_picker_element_shared.SkinTone;
            unicode: string;
            version: number;
        }[] | undefined;
    }[]>;
    loading: vue_demi.Ref<boolean>;
};
/**
 * Return a single emoji matching the shortcode, or null if not found.
 */
declare function useEmojiByShortcode(shortcode: MaybeRef<string>): {
    result: vue_demi.Ref<{
        name: string;
        shortcodes?: string[] | undefined;
        url: string;
        category?: string | undefined;
    } | {
        annotation: string;
        emoticon?: string | undefined;
        group: number;
        name: string;
        order: number;
        shortcodes?: string[] | undefined;
        tags?: string[] | undefined;
        version: number;
        unicode: string;
        skins?: {
            tone: emoji_picker_element_shared.SkinTone;
            unicode: string;
            version: number;
        }[] | undefined;
    } | null>;
    loading: vue_demi.Ref<boolean>;
};
/**
 * Return a single native emoji matching the unicode string, or a custom emoji matching the name, or null if not found.
 */
declare function useEmojiByUnicodeOrName(unicodeOrName: MaybeRef<string>): {
    result: vue_demi.Ref<{
        name: string;
        shortcodes?: string[] | undefined;
        url: string;
        category?: string | undefined;
    } | {
        annotation: string;
        emoticon?: string | undefined;
        group: number;
        name: string;
        order: number;
        shortcodes?: string[] | undefined;
        tags?: string[] | undefined;
        version: number;
        unicode: string;
        skins?: {
            tone: emoji_picker_element_shared.SkinTone;
            unicode: string;
            version: number;
        }[] | undefined;
    } | null>;
    loading: vue_demi.Ref<boolean>;
};

interface VuemojiPickerStyle {
    width?: string;
    height?: string;
    background?: string;
    borderColor?: string;
    borderSize?: string;
    buttonActiveBackground?: string;
    buttonHoverBackground?: string;
    categoryEmojiPadding?: string;
    categoryEmojiSize?: string;
    categoryFontColor?: string;
    categoryFontSize?: string;
    emojiPadding?: string;
    emojiSize?: string;
    indicatorColor?: string;
    indicatorHeight?: string;
    inputBorderColor?: string;
    inputBorderRadius?: string;
    inputFontColor?: string;
    inputFontSize?: string;
    inputLineHeight?: string;
    inputPadding?: string;
    inputPlaceholderColor?: string;
    numColumns?: string;
    outlineColor?: string;
    outlineSize?: string;
    skintoneBorderRadius?: string;
}

export { _default as VuemojiPicker, type VuemojiPickerStyle, useDatabase, useEmojiByGroup, useEmojiBySearchQuery, useEmojiByShortcode, useEmojiByUnicodeOrName };
